@@ -1,7 +1,9 @@
-from localshop.apps.packages.models import Package, Release, ReleaseFile
+from localshop.apps.packages.models import Package
 
 
 def sidebar(request):
+    if not request.user.is_authenticated():
+        return {'sidebar': {}}
     sidebar_local = (Package.objects
         .filter(is_local=True)
         .order_by('name')
@@ -12,4 +14,3 @@ def sidebar(request):
             'local': sidebar_local
         }
     }
-
